@@ -21,10 +21,7 @@ use Config::Model::Dpkg::Dependency;
 
 my $logger = get_logger("Backend::Dpkg::Control") ;
 
-sub read {
-    my $self = shift ;
-    my %args = @_ ;
-
+sub read ($self, %args) { ## no critic (ProhibitBuiltinHomonyms)
     # args is:
     # object     => $obj,         # Config::Model::Node object 
     # root       => './my_test',  # fake root directory, userd for tests
@@ -60,13 +57,25 @@ sub read {
     while (@$c ) {
         my ($section_line,$section) = splice @$c,0,2 ;
         my $package_name;
+        my @section_comment;
+      SECTION_LOOP:
         foreach (my $i = 0; $i < $#$section; $i += 2) {
-            next unless $section->[$i] =~ /^package$/i;
-            $package_name = $section->[ $i+1 ][0][0];
-            splice @$section,$i,2 ;
-            last ;
+            if ($section->[$i] =~ /^package$/i) {
+                # skip comment lines (plain scalar) before looking for
+                # package name (stored in first elt of array ref)
+                foreach my $section_data ( $section->[ $i+1 ]->@* ) {
+                    if (ref $section_data) {
+                        $package_name = $section_data->[0];
+                        splice @$section,$i,2 ;
+                        last SECTION_LOOP;
+                    }
+                    else {
+                        push @section_comment, $section_data;
+                    }
+                }
+            }
         }
-        
+
         if (not defined $package_name) {
             my $msg = "Cannot find package_name in section beginning at line $section_line";
             Config::Model::Exception::Syntax
@@ -74,6 +83,7 @@ sub read {
         }
 
         $node = $root->grab("binary:$package_name") ;
+        $node->annotation(@section_comment) if @section_comment;
         $self->read_sections ($node, $section_line, $section, $args{check});
     }
     return 1 ;
@@ -93,14 +103,15 @@ sub fill_package_cache ($self, $c) {
                 map { $packages{$_} = 1 }
                     grep { not /\$/ } # skip debhelper variables
                     map {
-                        chomp;
-                        s/\[.*\]//g; # remove arch details
-                        s/<.*>//;    # remove build profile
-                        s/\(.*\)//;  # remove version details
-                        s/\s//g;
-                        s/,\s*$//;   # remove trailing comma
-                        s/:\w+//;    # remove arch qualifier
-                        $_;
+                        my $l = $_;
+                        chomp $l;
+                        $l =~ s/\[.*\]//g; # remove arch details
+                        $l =~ s/<.*>//;    # remove build profile
+                        $l =~ s/\(.*\)//;  # remove version details
+                        $l =~ s/\s//g;
+                        $l =~ s/,\s*$//;   # remove trailing comma
+                        $l =~ s/:\w+//;    # remove arch qualifier
+                        $l;
                     }
                     grep { $_ }      # skip empty data
                     map { split /\s*[,|]\s*/ , $_->[0] } # extract dependency info from array ref
@@ -111,6 +122,7 @@ sub fill_package_cache ($self, $c) {
     }
     my @pkgs = keys %packages;
     Config::Model::Dpkg::Dependency::cache_info_from_madison ($self->node->instance,@pkgs);
+    return;
 }
 
 sub read_sections {
@@ -138,6 +150,7 @@ sub read_sections {
         my $ref = delete $sections{$lc_key} ;
         $self->store_section_element_in_tree ($node,$check, @$ref);
     }
+    return;
 }
 
 #
@@ -182,13 +195,11 @@ sub store_section_element_in_tree {
         my $unexpected_obj = $node->fetch_element($key);
         $self->store_section_leaf_element ( $logger, $unexpected_obj, $check, $v_ref);
     }
+    return;
 }
 
 
-sub write {
-    my $self = shift ;
-    my %args = @_ ;
-
+sub write ($self, %args) { ## no critic (ProhibitBuiltinHomonyms)
     # args is:
     # object     => $obj,         # Config::Model::Node object 
     # root       => './my_test',  # fake root directory, userd for tests
@@ -201,10 +212,13 @@ sub write {
 
     my $binary_hash = $node->fetch_element('binary') ;
     foreach my $binary_name ( $binary_hash -> fetch_all_indexes ) {
-        my $ref = [ Package => $binary_name ,
-                    $self->package_spec($binary_hash->fetch_with_id($binary_name)) ];
+        my $node = $binary_hash->fetch_with_id($binary_name);
+        my @section_lines = ();
+        my $c = $node->annotation ;
+        push @section_lines, map {'#'.$_} split /\n/,$c if $c ;
+        push @section_lines , Package => $binary_name , $self->package_spec($node) ;
 
-        push @sections, $ref ;
+        push @sections, \@section_lines ;
     }
 
     my $res = $self->write_dpkg_file(\@sections,",\n" ) ;
@@ -225,6 +239,7 @@ sub _re_order ($list, $move_after) {
         splice @$list, $ik, 1; # remove $k from list
         splice @$list, $iv, 0, $k; # add back $k after $v
     }
+    return;
 }
 
 my @move_after = (
