@@ -31,10 +31,7 @@ my %store_dispatch = (
     uniline => 'store_section_leaf_element',
 );
 
-sub read {
-    my $self = shift ;
-    my %args = @_ ;
-
+sub read ($self, %args) { ## no critic (ProhibitBuiltinHomonyms)
     # args is:
     # object     => $obj,         # Config::Model::Node object 
     # root       => './my_test',  # fake root directory, userd for tests
@@ -133,15 +130,15 @@ sub read {
         elsif (defined $section{license}) {
             # license_paragragh hash is used to contain license data indexed by license names
             # license name contains only one line
-            my ($v,$l, $a) = $section{license}[0]->@* ;
+            my ($v,$l, $author) = $section{license}[0]->@* ;
             # need to extract license name from license text
             my ($lic_name) = ($v =~ /^([^\n]+)/) ;
             if (not defined $lic_name) {
                 $lic_name = 'other';
-                $a = $section{license}[2] = q!use 'other' to replace undefined license name!;
+                $author = $section{license}[2] = q!use 'other' to replace undefined license name!;
             }
             if ($logger->is_debug) {
-                my $a_str = $a ? "altered: '$a' ":'' ;
+                my $a_str = $author ? "altered: '$author' ":'' ;
                 $logger->debug("Found license paragraph line $l, $a_str ($lic_name)");
              }
             $license_paragraph{$lic_name} = $section_ref ;
@@ -268,6 +265,7 @@ sub append_text_no_synopsis ($self, $logger_param, $object, $check, $v_ref) {
     }
 
     $self->store_section_leaf_element($logger_param,$object, $check, \@new_ref);
+    return;
 }
 
 sub _store_line {
@@ -276,6 +274,7 @@ sub _store_line {
     chomp $v ;
     $logger->debug("_store_line with check $check ".$object->name." = $v");
     $object->store(value => $v, check => $check) ; 
+    return;
 }
 
 sub _store_file_info ($self,$section, $object, $target_name,$key, $check, $v_ref) {
@@ -285,6 +284,7 @@ sub _store_file_info ($self,$section, $object, $target_name,$key, $check, $v_ref
     my $f =  $store_dispatch{$dispatcher}
         || die "Error in $section section (line ".$v_ref->[0][1]."): unexpected '$key' field\n";
     $self->$f($logger, $target,$check,$v_ref) ;
+    return;
 }
 
 sub _store_license_info ($self, $lic_node, $key, $check, $v_ref ) {
@@ -296,11 +296,13 @@ sub _store_license_info ($self, $lic_node, $key, $check, $v_ref ) {
         );
     }
     $self->_store_file_license( $lic_node, $check, $v_ref );
+    return;
 }
 
 sub _store_file_license ($self, $lic_object, $check, $v_ref) {
 
     return unless grep { /\S/ } map {$_->[0]} $v_ref->@*; # skip empty-ish value
+
     my ( $lic_line_ref, @lic_text_ref ) = $v_ref->@*;
     my $lic_line = $lic_line_ref->[0];
     $logger->debug("_store_file_license check $check called on ".$lic_object->name);
@@ -316,12 +318,10 @@ sub _store_file_license ($self, $lic_object, $check, $v_ref) {
 
     my $short_name_obj = $lic_object->fetch_element('short_name');
     $self->store_section_leaf_element ($logger, $short_name_obj, $check, [ $lic_line_ref ]);
+    return;
 }
 
-sub write {
-    my $self = shift;
-    my %args = @_;
-
+sub write ($self, %args) { ## no critic (ProhibitBuiltinHomonyms)
     # args is:
     # object     => $obj,         # Config::Model::Node object
     # root       => './my_test',  # fake root directory, userd for tests
@@ -459,7 +459,9 @@ license information in Debian source package format.
 
 =head1 CONSTRUCTOR
 
-=head2 new ( node => $node_obj, name => 'Dpkg::Copyright' ) ;
+=head2 new
+
+Parameters: C<< node => $node_obj, name => 'Dpkg::Copyright' >>
 
 Inherited from L<Config::Model::Backend::Any>. The constructor will be
 called by L<Config::Model::AutoRead>.
