@@ -206,10 +206,11 @@ my $grammar = << 'EOG' ;
     } ;
     my $arch_list = qr/(any |alpha|amd64
          |arm(64|eb|el|hf)?
-         |avr32 |hppa |i386 |ia64 |lpia |m32r |m68k
+         |avr32 |hppa |loong64 |i386 |ia64 |lpia |m32r |m68k
          |mips(el|64el|64)?
          |powerpc(el|spe)?
          |ppc64\b |ppc64el |s390x?
+         |riscv64
          |sh3\b |sh3eb |sh4\b |sh4eb |sparc\b |sparc64 |x32 )/x;
 }
 
