@@ -13,6 +13,7 @@ use YAML::PP qw/LoadFile/;
 use Path::Tiny;
 use List::MoreUtils qw/binsert bremove bsearch/;
 use Log::Log4perl qw(get_logger :levels);
+use Config::IniFiles;
 
 use Software::Copyright;
 use Dpkg::Copyright::Grant::Plain;
@@ -412,12 +413,37 @@ my $__extract_rakudoc_info = sub ($file, $grant, $current_dir) {
     return;
 };
 
+my $__extract_dist_ini_info = sub ($file, $grant, $current_dir) {
+    my $dist_ini = $current_dir->child($file);
+
+    if ($dist_ini->is_file) {
+        my $cfg = Config::IniFiles->new(
+            -file => $dist_ini->stringify,
+            -fallback => 'top',
+        );
+        $grant->license($cfg->val(qw/top license/)) if $cfg->exists(qw/top license/);
+
+        if ($cfg->exists(qw/top copyright_holder/) or $cfg->exists(qw/top copyright_year/)) {
+            $grant->copyright(new_sc(
+                $cfg->val(top => copyright_year => '') . ', ' .
+                $cfg->val(top => copyright_holder => '')
+            ));
+        }
+    }
+    return;
+};
+
 my $__extract_rust_info = sub ($file, $grant, $current_dir) {
     my $cargotoml = $current_dir->child($file);
 
     if ($cargotoml->is_file) {
         my $toml = $cargotoml->slurp_utf8;
-        my $data_raw = from_toml($toml);
+
+        my $data_raw = eval {from_toml($toml);};
+        if ($@) {
+            warn "Error while parsing $cargotoml: $@";
+            return;
+        }
 
         # cope with https://doc.rust-lang.org/cargo/reference/workspaces.html
         my $data = $data_raw->{workspace} // $data_raw;
@@ -444,7 +470,14 @@ my $__extract_nodejs_info = sub ($c_key, $l_key, $file, $grant, $current_dir) {
     my $json_file = $current_dir->child($file);
 
     if ($json_file->is_file) {
-        my $data = from_json($json_file->slurp_utf8);
+        my $json = $json_file->slurp_utf8;
+        # remove crap like BOM
+        $json =~ s/^[^{]+//;
+        my $data = eval { from_json($json) };
+        if ($@) {
+            warn "Error while parsing $json_file: $@";
+            return;
+        }
 
         my @c_data;
         if  (ref $data->{$c_key}) {
@@ -524,6 +557,7 @@ my %override = (
     'META.json' => sub {$__extract_json_info->('author','license',@_)},
     'META6.json' => sub {$__extract_json_info->('authors','license',@_)},
     'README.rakudoc' => $__extract_rakudoc_info,
+    'dist.ini' => $__extract_dist_ini_info,
     'LICENSE' => $_cleanup_license,
     'LICENCE' => $_cleanup_license,
 );
