@@ -206,6 +206,10 @@ my @tests = (
             'source XS-Ruby-Versions' => 'all',
             'binary:libfast-xs-ruby XB-Ruby-Versions' => '${ruby:Versions}',
         },
+        file_contents_unlike => {
+            # XB-Ruby is now deprecated (See https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=1075762)
+            "debian/control" => qr/XB-Ruby/
+        },
     },
     {
         # test for #903905,  XS-Ruby-Versions in a package not maintained
@@ -215,6 +219,10 @@ my @tests = (
             'source XS-Ruby-Versions' => 'all',
             'binary:ruby-rgfa XB-Ruby-Versions' => '${ruby:Versions}',
         },
+        file_contents_unlike => {
+            # XB-Ruby is now deprecated (See https://bugs.debian.org/cgi-bin/bugreport.cgi?bug=1075762)
+            "debian/control" => qr/XB-Ruby/
+        },
     },
     {
         # test for XS-Testsuite field
